@@ -18,13 +18,13 @@ use 5.006_000;
 use strict;
 use Cwd;
 use Dpkg::IPC;
-use Dpkg::Compression;
 use File::Copy qw(cp move);
 use File::Basename;
 use File::Spec;
 use File::Path qw/ rmtree /;
 use File::Temp qw/ tempdir tempfile /;
-use lib '/usr/share/devscripts';
+BEGIN { push @INC, '/usr/share/devscripts'; }
+use Devscripts::Compression;
 use Devscripts::Versort;
 
 # Predeclare functions
@@ -39,6 +39,8 @@ my $modified_conf_msg;
 my $exit_status = 0;
 my $dummyname = "---DUMMY---";
 
+my $compression_re = compression_get_file_extension_regex();
+
 sub usage {
     print <<"EOF";
 Usage: $progname [option]
@@ -93,6 +95,8 @@ Valid options are:
 
 Default settings modified by devscripts configuration files:
 $modified_conf_msg
+
+Use the debbindiff package for deeper comparisons of .deb files.
 EOF
 }
 
@@ -501,7 +505,7 @@ elsif ($type eq 'dsc') {
 		if ($file =~ /\.diff\.gz$/) {
 		    $diffs[$i] = cwd() . '/' . $file;
 		}
-		elsif ($file =~ /((?:\.orig)?\.tar\.$compression_re_file_ext|\.git)$/) {
+		elsif ($file =~ /((?:\.orig)?\.tar\.$compression_re|\.git)$/) {
 		    $origs[$i] = $file;
 		}
 	    } else {
@@ -629,7 +633,7 @@ elsif ($type eq 'dsc') {
 	while ($_ = readdir(DIR)) {
 		my $unpacked = "=unpacked-tar" . $tarballs . "=";
 		my $filename = $_;
-		if ($filename =~ s/\.tar\.$compression_re_file_ext$//) {
+		if ($filename =~ s/\.tar\.$compression_re$//) {
 		    my $comp = compression_guess_from_filename($_);
 		    $tarballs++;
 		    spawn(exec => ['tar', "--$comp", '-xf', $_],
